import 'package:_private_core/_private_core.dart'; 
import '../resources.dart';

class SellerRepository {
  SellerRepository._();

  static SellerRepository? _instance;

  factory SellerRepository([AppApi? api]) {
    _instance ??= SellerRepository._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<SellerMissionModel>> getMissionsFromSeller(
      {required lat,
      required lng,
      distance = 10000,
      subcatId,
      languageCode}) async {
    Map<String, dynamic> params = {
      'lat': lat,
      'lng': lng,
      'distance': distance,
      'languageCode': languageCode ?? appPrefs.languageCode
    };
    if (subcatId != null) params.addAll({'subcatId': subcatId});
    NetworkResponse response = await _api.getMissionsFromSeller(params);
    return response.data ?? [];
  }

  Future<List<MissionTypeModel>> getMissionTypes({typeId, languageCode}) async {
    Map<String, dynamic> params = {
      'languageCode': languageCode ?? appPrefs.languageCode
    };
    if (typeId != null) params.addAll({'typeId': typeId});
    NetworkResponse response = await _api.getMissionTypes(params);
    return response.data ?? [];
  }

  Future<UpdateInfoResult> checkUpdateEmailFromUser(email) async {
    NetworkResponse response = await _api.checkUpdateEmailFromUser(email);
    return response.data ?? UpdateInfoResult(status: false);
  }

  Future<String?> confirmUpdateUserEmailCode(email, code, phone) async {
    NetworkResponse response =
        await _api.confirmUpdateUserEmailCode(email, code, phone);
    return response.data;
  }

  Future<bool> updateUserEmail(token) async {
    NetworkResponse response = await _api.updateUserEmail(token);
    return response.data ?? false;
  }

  Future<String?> updateImageForBecomeSeller(fileType, path) async {
    NetworkResponse response =
        await _api.updateImageForBecomeSeller(fileType, path);
    return response.data;
  }

  Future<bool> becomeSeller(confirmed) async {
    NetworkResponse response = await _api.becomeSeller(confirmed);
    return response.data ?? false;
  }

  Future<bool> quitSellerProgram(temporary) async {
    NetworkResponse response = await _api.quitSellerProgram(temporary);
    return response.data ?? false;
  }

  Future<bool> recoverySellerProgram() async {
    NetworkResponse response = await _api.recoverySellerProgram();
    return response.data ?? false;
  }

  Future<bool> takeMissionFromSeller(missionId) async {
    NetworkResponse response = await _api.takeMissionFromSeller(missionId);
    return response.data ?? false;
  }

  Future<NumberOfSaleModel?> getNumberOfSalesFromSellers([languageCode]) async {
    Map<String, dynamic> params = {
      'languageCode': languageCode ?? appPrefs.languageCode
    };
    NetworkResponse response = await _api.getNumberOfSalesFromSellers(params);
    return response.data;
  }

  Future<BankAccountModel?> setBankAccountFromUser(
      {fullName,
      accountType,
      bankName,
      currency,
      swiftCode,
      bicCode,
      bankAddress,
      cryptoWalletaddress,
      accountNumber}) async {
    Map<String, dynamic> params = {
      "fullName": fullName,
      "accountType": accountType,
      "bankName": bankName,
      "currency": currency,
      "swiftCode": swiftCode,
      "bicCode": bicCode,
      "bankAddress": bankAddress,
      "cryptoWalletaddress": cryptoWalletaddress,
      "accountNumber": accountNumber,
    };
    NetworkResponse response = await _api.setBankAccountFromUser(params);
    return response.data;
  }

  Future<BankAccountModel?> updateBankInfosFromSeller(
      {fullName,
      accountType,
      bankName,
      currency,
      swiftCode,
      bicCode,
      bankAddress,
      cryptoWalletaddress,
      accountNumber}) async {
    Map<String, dynamic> params = {
      "fullName": fullName,
      "accountType": accountType,
      "bankName": bankName,
      "currency": currency,
      "swiftCode": swiftCode,
      "bicCode": bicCode,
      "bankAddress": bankAddress,
      "cryptoWalletaddress": cryptoWalletaddress,
      "accountNumber": accountNumber,
    };
    NetworkResponse response = await _api.updateBankInfosFromSeller(params);
    return response.data;
  }

  Future<List<BankAccountTypeModel>> getAccountTypes() async {
    NetworkResponse response = await _api.getAccountTypes();
    return response.data ?? [];
  }

  Future<BankAccountModel?> getBankInfosFromSeller() async {
    NetworkResponse response = await _api.getBankInfosFromSeller();
    return response.data;
  }
}
